import{_ as i,C as n}from"./View.vue_vue_type_script_setup_true_lang.69e51c6f.js";import{d as p,ei as s,a as m,u as a,o as c}from"./jwt-decode.esm.47f59010.js";import"./router.cfb03f89.js";import"./index.8995a499.js";import"./fetch.e0dfa394.js";import"./record.30ff6eef.js";import"./SaveButton.986667ef.js";import"./ExclamationCircleOutlined.ad66211a.js";import"./CrudView.789b533f.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.a2b3eeb7.js";import"./constants.bbfdfb21.js";import"./url.4ba49005.js";import"./PhDotsThreeVertical.vue.e9c6f787.js";import"./index.12e6cfe2.js";import"./asyncComputed.febe2b11.js";import"./omniChatStore.07f62bd5.js";import"./uuid.2075c158.js";import"./PhCopySimple.vue.d9213ca9.js";import"./PhPencil.vue.3586175f.js";import"./useCodebaseEvents.3542d20f.js";import"./contracts.generated.3f22c968.js";import"./index.76cbd30f.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="33b3fcb5-84cd-47df-88e4-bfa7fe89cb0b",o._sentryDebugIdIdentifier="sentry-dbid-33b3fcb5-84cd-47df-88e4-bfa7fe89cb0b")}catch{}})();const A=p({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new n(e);return(d,f)=>(c(),m(i,{"env-var-repository":a(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.0dfba770.js.map
