import{d as a,o as d,ac as s,e as l,ae as r,eh as n,_ as c}from"./jwt-decode.esm.47f59010.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="6e548a44-bc25-4ac7-b7e9-327c1e98036e",t._sentryDebugIdIdentifier="sentry-dbid-6e548a44-bc25-4ac7-b7e9-327c1e98036e")}catch{}})();const i=a({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean}},setup(t){return(e,o)=>(d(),s("div",{class:n(["content-layout",{"no-padding":e.noPadding}])},[l("div",{class:n(["centered-layout",{"full-width":e.fullWidth}])},[r(e.$slots,"default",{},void 0,!0)],2)],2))}});const _=c(i,[["__scopeId","data-v-fb4d67f9"]]);export{_ as C};
//# sourceMappingURL=ContentLayout.c133929b.js.map
