import{A as o}from"./index.d408b03e.js";import{d as a,c as r,ac as p,f as d,u as f,eh as l,h as c,o as i,_ as u}from"./jwt-decode.esm.47f59010.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="4e0800f4-93b3-49db-9fa8-f1a4a6ebed50",e._sentryDebugIdIdentifier="sentry-dbid-4e0800f4-93b3-49db-9fa8-f1a4a6ebed50")}catch{}})();const _=a({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,n=r(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(t,m)=>t.stepsInfo?(i(),p("nav",{key:0,class:l(["p-steps",{"full-screen":!t.isPreview}])},[d(f(o),{current:t.stepsInfo.current-1,items:n.value,responsive:!1},null,8,["current","items"])],2)):c("",!0)}});const I=u(_,[["__scopeId","data-v-58fdd395"]]);export{I as S};
//# sourceMappingURL=Steps.95771774.js.map
