import{O as l}from"./workspaceStore.9693f43b.js";import{d as c,U as u,ac as _,f as o,b as n,u as a,o as f,g as d,t as r,i as s,A as p,df as g}from"./jwt-decode.esm.47f59010.js";import"./userStore.e8304ebc.js";import"./url.4ba49005.js";import"./colorHelpers.939427f5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="671574e8-769c-49e9-9844-d0dd6d1493e7",e._sentryDebugIdIdentifier="sentry-dbid-671574e8-769c-49e9-9844-d0dd6d1493e7")}catch{}})();const v=c({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new l().logoutCallback()}),(t,i)=>(f(),_("div",null,[o(a(p),null,{default:n(()=>[d(r(a(s).translate("i18n_oidclogoutcallback_authenticated_title")),1)]),_:1}),o(a(g),null,{default:n(()=>[d(r(a(s).translate("i18n_oidclogoutcallback_close_window_message")),1)]),_:1})]))}});export{v as default};
//# sourceMappingURL=OidcLogoutCallback.f471ecec.js.map
