import{O as l}from"./workspaceStore.9693f43b.js";import{d as c,U as u,ac as f,f as n,b as d,u as a,o as _,g as o,t as r,i,A as b,df as p}from"./jwt-decode.esm.47f59010.js";import"./userStore.e8304ebc.js";import"./url.4ba49005.js";import"./colorHelpers.939427f5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6bc75e02-db7d-409a-a37b-0d1dd03eb0fe",e._sentryDebugIdIdentifier="sentry-dbid-6bc75e02-db7d-409a-a37b-0d1dd03eb0fe")}catch{}})();const v=c({__name:"OidcLoginCallback",setup(e){return u(async()=>{await new l().loginCallback()}),(t,s)=>(_(),f("div",null,[n(a(b),null,{default:d(()=>[o(r(a(i).translate("i18n_oidclogincallback_authenticated_title")),1)]),_:1}),n(a(p),null,{default:d(()=>[o(r(a(i).translate("i18n_oidclogincallback_close_window_message")),1)]),_:1})]))}});export{v as default};
//# sourceMappingURL=OidcLoginCallback.8216e341.js.map
