import{P as f}from"./PlayerNavbar.7c0453f2.js";import{d as g,ec as h,ei as c,r as y,c as k,j as v,ac as b,u as a,a as w,h as L,e as C,f as I,o as i,_ as N}from"./jwt-decode.esm.47f59010.js";import{u as V}from"./workspaceStore.9693f43b.js";import"./userStore.e8304ebc.js";import"./metadata.69e468d6.js";import"./PhWebhooksLogo.vue.e7321653.js";import"./LoadingOutlined.2d29f0e1.js";import"./PhSignOut.vue.9eb21b1c.js";import"./index.63e70668.js";import"./url.4ba49005.js";import"./colorHelpers.939427f5.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="ee4f3a10-3963-46d8-9641-f67cb34286d8",o._sentryDebugIdIdentifier="sentry-dbid-ee4f3a10-3963-46d8-9641-f67cb34286d8")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),d=c().path,n=y(null),u=async({path:s,id:r})=>{n.value=r,await e.push({path:`/${s}`}),n.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=k(()=>!!c().meta.hideLogin);return(s,r)=>{const m=v("RouterView");return i(),b("div",x,[a(t).state.workspace?(i(),w(f,{key:0,"current-path":a(d),"hide-login":_.value,"runner-data":a(t).state.workspace,loading:n.value,onNavigate:u,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const F=N(D,[["__scopeId","data-v-f095bece"]]);export{F as default};
//# sourceMappingURL=Main.3afc4ba4.js.map
