import{C as r,E as t,K as i,a as c,M as l,c as y,P as f,R as g,S as u,b,T as k,U as p,e as w,l as D}from"./toggleHighContrast.fa77fdf8.js";import"./jwt-decode.esm.47f59010.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="2e3d6081-6d71-4ada-a42e-078850a4ceea",e._sentryDebugIdIdentifier="sentry-dbid-2e3d6081-6d71-4ada-a42e-078850a4ceea")}catch{}})();export{r as CancellationTokenSource,t as Emitter,i as KeyCode,c as KeyMod,l as MarkerSeverity,y as MarkerTag,f as Position,g as Range,u as Selection,b as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.2f21f781.js.map
