import{C as n,D as r,E as o,F as c,P as d,G as p,H as f,I as b,J as a,K as m,L as u,N as g,O as l}from"./jwt-decode.esm.47f59010.js";import{a as y,b as i}from"./router.ae5c14de.js";import{s as w}from"./workspaceStore.9693f43b.js";import{_ as h}from"./App.vue_vue_type_style_index_0_lang.08210ecb.js";import"./userStore.e8304ebc.js";import"./url.4ba49005.js";import"./colorHelpers.939427f5.js";import"./PlayerConfigProvider.f0eaf9f3.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="b93bf2cb-8c4d-49f8-8318-6eb1e2ce8033",t._sentryDebugIdIdentifier="sentry-dbid-b93bf2cb-8c4d-49f8-8318-6eb1e2ce8033")}catch{}})();class I{static init(){setInterval(()=>{fetch("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await y(),s=n(),e=r({render:()=>m(h)});o.init(),c(e,i,t),I.init(),e.use(i),e.use(s),e.use(d),e.mount("#app"),e.component("VSelect",p),e.component("Markdown",f),e.component("Message",b),a(e,u),a(e,g),a(e,l)})();
//# sourceMappingURL=player.ebf3133f.js.map
