import{d,eF as c,c as r,o,ac as t,h as l,eh as f,t as _,_ as p}from"./jwt-decode.esm.47f59010.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="94237ec5-85aa-4437-a0f7-3f908b8f2af4",e._sentryDebugIdIdentifier="sentry-dbid-94237ec5-85aa-4437-a0f7-3f908b8f2af4")}catch{}})();const u={class:"logo"},g=["src","alt"],m=d({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const a=e;c(s=>({"4521d904":n.value}));const n=r(()=>a.size==="small"?"24px":a.size==="large"?"80px":"50px"),i=r(()=>`${a.brandName} Logo`);return(s,y)=>(o(),t("div",u,[s.imageUrl?(o(),t("img",{key:0,class:"logo-img",src:s.imageUrl,alt:i.value},null,8,g)):l("",!0),s.hideText?l("",!0):(o(),t("span",{key:1,class:f(s.size)},_(s.brandName),3))]))}});const h=p(m,[["__scopeId","data-v-8f34aac0"]]);export{h as L};
//# sourceMappingURL=Logo.e86b6b23.js.map
