import{_ as f}from"./Login.vue_vue_type_script_setup_true_lang.ab4402e7.js";import{d as l,ec as m,ei as g,ac as y,f as b,u as n,o as w,_ as k}from"./jwt-decode.esm.47f59010.js";import{u as h}from"./workspaceStore.9693f43b.js";import"./CircularLoading.daf759d9.js";import"./Logo.e86b6b23.js";import"./string.39c8a903.js";import"./index.76cbd30f.js";import"./userStore.e8304ebc.js";import"./url.4ba49005.js";import"./colorHelpers.939427f5.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="f55e5b21-7410-42ff-aa5c-b110635ce0c0",e._sentryDebugIdIdentifier="sentry-dbid-f55e5b21-7410-42ff-aa5c-b110635ce0c0")}catch{}})();const v={class:"runner"},I=l({__name:"Login",setup(e){const o=m(),t=g(),r=h(),_=async()=>{const{redirect:a,...s}=t.query;if(a){await o.push({path:a,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>{var c,p,u,i,d;return w(),y("div",v,[b(f,{"logo-url":(p=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?p:void 0,"brand-name":(u=n(r).state.workspace)==null?void 0:u.brandName,locale:(d=(i=n(r).state.workspace)==null?void 0:i.language)!=null?d:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const H=k(I,[["__scopeId","data-v-12c690e1"]]);export{H as default};
//# sourceMappingURL=Login.8e13b15d.js.map
