import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.e1cfa824.js";import{B as m}from"./BaseLayout.2a82be24.js";import{d as l,al as y,c8 as v,_ as u,b4 as b,b5 as g,o as _,ac as h,e as a,ad as n,ei as w,ec as S,U as L,a as k,b as s,f as i,u as x}from"./jwt-decode.esm.47f59010.js";import{u as B}from"./editor.11a4f0cf.js";import{A as I}from"./index.5eeedb69.js";import"./Logo.e86b6b23.js";import"./router.ae5c14de.js";import"./workspaceStore.9693f43b.js";import"./userStore.e8304ebc.js";import"./url.4ba49005.js";import"./colorHelpers.939427f5.js";import"./useCodebaseEvents.3542d20f.js";import"./contracts.generated.3f22c968.js";import"./index.8995a499.js";import"./constants.bbfdfb21.js";import"./linters.9f818fd6.js";import"./asyncComputed.febe2b11.js";import"./Breadcrumb.c8da3019.js";import"./index.63e70668.js";import"./index.12e6cfe2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="30b822e6-d85e-4a58-bc41-00737e05f078",e._sentryDebugIdIdentifier="sentry-dbid-30b822e6-d85e-4a58-bc41-00737e05f078")}catch{}})();const $=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=y({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...v(o)}}});const P={class:"v-spinner"};function D(e,o,r,d,c,p){return b((_(),h("div",P,[a("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-even",style:n(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const R=u($,[["render",D],["__scopeId","data-v-06538001"]]),j={class:"content"},z=l({__name:"ProjectLogin",setup(e){const o=w(),r=S(),d=B();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),r.replace(t.pathname+t.search)}function p(){const t=o.query["api-key"];if(typeof t=="string")return t}return L(async()=>{const t=p();if(!t){r.push({name:"error"});return}await d.createLogin(t).then(c),r.push({name:"editor"})}),(t,A)=>(_(),k(m,null,{navbar:s(()=>[i(x(I),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:s(()=>[i(f)]),_:1})]),content:s(()=>[a("div",j,[i(R)])]),_:1}))}});const te=u(z,[["__scopeId","data-v-d2a19803"]]);export{te as default};
//# sourceMappingURL=ProjectLogin.83ae9c4c.js.map
