import"./jwt-decode.esm.47f59010.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="648152d9-5346-41a6-8eb8-cf12a010241c",e._sentryDebugIdIdentifier="sentry-dbid-648152d9-5346-41a6-8eb8-cf12a010241c")}catch{}})();const o=(...e)=>window.fetch(...e);export{o as l};
//# sourceMappingURL=fetch.e0dfa394.js.map
