import{W as c,dQ as i,dR as d}from"./jwt-decode.esm.47f59010.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="09268068-d961-487b-a28a-01a82cb03a1f",e._sentryDebugIdIdentifier="sentry-dbid-09268068-d961-487b-a28a-01a82cb03a1f")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:a,YearPicker:f,TimePicker:m,QuarterPicker:r,RangePicker:o}=i(d),u=c(n,{WeekPicker:t,MonthPicker:a,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:r,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(a.name,a),e.component(t.name,t),e.component(r.name,r),e)});export{u as D,a as M,r as Q,o as R,t as W};
//# sourceMappingURL=dayjs.8c9480e7.js.map
