import{d as o,o as s,ac as d,f as a,u as _,S as r,_ as c}from"./jwt-decode.esm.47f59010.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="bb3e26f0-690f-4575-914d-b0d969c35c18",e._sentryDebugIdIdentifier="sentry-dbid-bb3e26f0-690f-4575-914d-b0d969c35c18")}catch{}})();const i={class:"centered"},f=o({__name:"LoadingContainer",setup(e){return(n,t)=>(s(),d("div",i,[a(_(r))]))}});const u=c(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.4430af86.js.map
