import"./jwt-decode.esm.47f59010.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="a6892e89-bb58-4356-9c23-354753c960c8",t._sentryDebugIdIdentifier="sentry-dbid-a6892e89-bb58-4356-9c23-354753c960c8")}catch{}})();const e={HOMEPAGE:{}.VITE_HOMEPAGE_URL||"https://abstra.io",DOCS:{}.VITE_DOCS_URL||"https://abstra.io/docs",CLOUD:{}.VITE_CONSOLE_URL||"https://cloud.abstra.io",GITHUB:{}.VITE_GITHUB_URL||"https://github.com/abstra-app/abstra-lib"},o=t=>{if(!t)return e.DOCS;const s=t.startsWith("/")?t.slice(1):t;return`${e.DOCS}/${s}`};export{e as A,o as b};
//# sourceMappingURL=constants.bbfdfb21.js.map
